@@ -4,7 +4,7 @@ use namespace::autoclean;
 extends 'Algorithm::Simplex';
 with 'Algorithm::Simplex::Role::Solve';
 
-my $one     = 1;
+my $one     =  1;
 my $neg_one = -1;
 my $EMPTY_STRING = q();
 
@@ -54,6 +54,15 @@ sub pivot {
     }
 }
 
+# Count pivots made 
+after 'pivot' => sub {
+    my $self = shift;
+    # TODO: Confirm whether clear is needed or not. Appears not in testing.
+    # $self->clear_display_tableau; 
+    $self->number_of_pivots_made( $self->number_of_pivots_made + 1 );
+    return;
+};
+
 =head2 tableau_is_optimal
 
 Check the basement row to see if any positive entries exist.  Existence of
@@ -163,12 +172,6 @@ sub current_solution {
     return (\%primal_solution, \%dual_solution);
 }
 
-sub display_tableau {
-    my $self = shift;
-
-    return  $self->tableau;
-}
-
 __PACKAGE__->meta->make_immutable;
 
 1;
